--------------------------------------------------------------------------------
-- Weapon Banana Bazooka + Projectile Banana
-- Script by Arne, April 2011
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.bbazooka={}
cc.bbazooka.banana={}

-- Load & Prepare Ressources
cc.bbazooka.gfx_wpn=loadgfx("weapons/bananalauncher.bmp")					-- Weapon Image
setmidhandle(cc.bbazooka.gfx_wpn)
cc.bbazooka.gfx_pro=loadgfx("weapons/banana.bmp")					-- Projectile Image
setmidhandle(cc.bbazooka.gfx_pro)
cc.bbazooka.sfx_attack=loadsfx("splat.wav")							-- Attack sound

--------------------------------------------------------------------------------
-- Weapon: Banana Bazooka
--------------------------------------------------------------------------------

cc.bbazooka.id=addweapon("cc.bbazooka","Banana Bazooka",cc.bbazooka.gfx_pro)	-- Add Weapon
cc.bbazooka.ammo=3													-- 3 Bananas

function cc.bbazooka.draw()											-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	drawinhand(cc.bbazooka.gfx_wpn,6,0)
	-- HUD ammobar
	if cc.bbazooka.ammo-weapon_shots>0 then
		hudammobar(cc.bbazooka.ammo-weapon_shots,cc.bbazooka.ammo)
	end
	-- HUD Crosshair
	if cc.bbazooka.ammo-weapon_shots>0 then
		hudcrosshair(7,3)
	end
end

function cc.bbazooka.attack(attack)									-- Attack
	-- Decrement timer
	if weapon_timer>0 then
		weapon_timer=weapon_timer-1
	end
	if (weapon_shots<cc.bbazooka.ammo) and (attack==1) and (weapon_timer<=0) then
			-- No more weapon switching!
		useweapon(0)
		playsound(cc.bbazooka.sfx_attack)
		weapon_shots=weapon_shots+1
		weapon_timer=15
		id=createprojectile(cc.bbazooka.banana.id)
		projectiles[id]={}
		-- Ignore collision with current player at beginning
		projectiles[id].ignore=playercurrent()
		-- Set initial position of projectile
		projectiles[id].x=getplayerx(0)+(6*getplayerdirection(0))+math.sin(math.rad(getplayerrotation(0)))*10.0
		projectiles[id].y=getplayery(0)+3-math.cos(math.rad(getplayerrotation(0)))*10.0
		-- Initial movement
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*20
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*20
		projectiles[id].x=projectiles[id].x-projectiles[id].sx
		projectiles[id].y=projectiles[id].y-projectiles[id].sy
		cc.bbazooka.banana.move(id,0)
		-- Set speed of projectile
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*10.0
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*10.0
		-- Effects
		recoil(1)
		-- End Turn
		if weapon_shots>=cc.bbazooka.ammo then
			endturn()
		end
	end
end


--------------------------------------------------------------------------------
-- Projectile: Banana
--------------------------------------------------------------------------------

cc.bbazooka.banana.id=addprojectile("cc.bbazooka.banana")		-- Add Projectile

function cc.bbazooka.banana.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.bbazooka.gfx_pro,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.bbazooka.banana.update(id)						-- Update
	-- Move
	cc.bbazooka.banana.move(id,1)
end

function cc.bbazooka.banana.move(id,fx)
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Particle Tail
	if (fx==1) then
		particle(p_smoke,projectiles[id].x-math.sin(math.rad(rot))*7,projectiles[id].y+math.cos(math.rad(rot))*7)
		particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
		particlefadealpha(0.01)
	end
	-- Wind + Gravity influence on speed
	projectiles[id].sy=projectiles[id].sy+getgravity()
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*3,projectiles[id].y-math.cos(math.rad(rot))*3)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				playsound(cc.bbazooka.sfx_attack)
				-- Cause damage
				arealdamage(projectiles[id].x,projectiles[id].y,50,30)
				-- Destroy terrain
				terrainexplosion(projectiles[id].x,projectiles[id].y,25,1)
				-- Crater
				if math.random(0,1)==1 then
					terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,180,180,0)
				else
					terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,180,180,0)
				end
				-- Free projectile
				freeprojectile(id)
				break
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			-- Free projectile
			freeprojectile(id)
			break
		end
	end
end