--------------------------------------------------------------------------------
-- Weapon Dragon Strike + Projectile Dragon + Projectile Fire
-- Script by Arne, November 2011
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.dragon={}
cc.dragon.dragon={}
cc.dragon.fire={}

-- Load & Prepare Ressources
cc.dragon.gfx_wpn=loadgfx("weapons/Dragonstrike.png")					-- Weapon Image
setmidhandle(cc.dragon.gfx_wpn)
cc.dragon.gfx_dragon1=loadgfx("weapons/Dragon1.png")				-- Dragon Frame 1
setmidhandle(cc.dragon.gfx_dragon1)
cc.dragon.gfx_dragon2=loadgfx("weapons/Dragon2.png")				-- Dragon Frame 2
setmidhandle(cc.dragon.gfx_dragon2)
cc.dragon.sfx_roar=loadsfx("Dragonroar.ogg")						-- Dragon Roar Sound
cc.dragon.sfx_fire=loadsfx("Dragonfire.ogg")						-- Firebreath Sound

--------------------------------------------------------------------------------
-- Weapon: Dragon Strike
--------------------------------------------------------------------------------

cc.dragon.id=addweapon("cc.dragon","Dragon Strike",cc.dragon.gfx_wpn,0,3,"airborne")	-- Add Weapon (0 uses, first in round 3)

function cc.dragon.draw()										-- Draw
	-- Do nothing
end

function cc.dragon.attack(attack)								-- Attack
	if (weapon_shots<=0) then
		if attack==1 then
			-- No more weapon switching!
			useweapon(0)
			playsound(cc.dragon.sfx_roar)
			weapon_shots=weapon_shots+1
			id=createprojectile(cc.dragon.dragon.id)
			projectiles[id]={}
			-- Set initial position of projectile
			projectiles[id].x=-100
			projectiles[id].y=-150
			-- End Turn
			endturn()
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: Dragon
--------------------------------------------------------------------------------

cc.dragon.dragon.id=addprojectile("cc.dragon.dragon")			-- Add Projectile

function cc.dragon.dragon.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	setrotation(0)
	-- Draw projectile
	weapon_timer=weapon_timer+1
	if weapon_timer>=10 then
		weapon_timer=0
		weapon_mode=1-weapon_mode
	end
	if weapon_mode==0 then
		drawimage(cc.dragon.gfx_dragon1,projectiles[id].x,projectiles[id].y)
	else
		drawimage(cc.dragon.gfx_dragon2,projectiles[id].x,projectiles[id].y)
	end
end

function cc.dragon.dragon.update(id)					-- Update
	-- Move
	projectiles[id].x=projectiles[id].x+5
	-- In Drop Area?
	if projectiles[id].x<=(getmapwidth()) then
			randomseed(getframe()*1415)
			if (random(1,100)<=25) then
		-- Drop Stuff
		if math.mod(projectiles[id].x,50)==0 then
			-- Drop Fire
			playsound(cc.dragon.sfx_fire)
			pid=createprojectile(cc.dragon.fire.id)
			projectiles[pid]={}
			projectiles[pid].x=projectiles[id].x-30
			projectiles[pid].y=projectiles[id].y
			projectiles[pid].sx=0
			projectiles[pid].sy=2
			projectiles[pid].timer=5*50
		createobject(o_fire,projectiles[id].x,projectiles[id].y)
		for a=45,360,45 do
		createobject(o_fire,projectiles[id].x+math.sin(math.rad(a))*25,projectiles[id].y-math.cos(math.rad(a))*20)
			end
		end
		else
		-- NADA
	end
		-- Scroll to projectile
		scroll(projectiles[id].x,projectiles[id].y)
	-- Free projectile
	elseif projectiles[id].x>(getmapwidth()+500) then
		-- Free projectile
		freeprojectile(id)
	end
end

--------------------------------------------------------------------------------
-- Projectile: Fire
--------------------------------------------------------------------------------

cc.dragon.fire.id=addprojectile("cc.dragon.fire")	-- Add Projectile

function cc.dragon.fire.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	setrotation(0)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.dragon.fire.update(id)							-- Update
-- 		Particle Tail
	particle(p_smoke,projectiles[id].x,projectiles[id].y)
	particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
	particlefadealpha(0.01)
	particle(p_lightpuff,projectiles[id].x,projectiles[id].y)
	particlefadealpha(0.04)
	if getframe()%3==1 then
		particle(p_spark,projectiles[id].x,projectiles[id].y)
	end
	-- Wind + Gravity influence on speed
	projectiles[id].sy=projectiles[id].sy+getgravity()
	projectiles[id].sx=projectiles[id].sx+getwind()*0.5
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/5)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		-- Move X
		projectiles[id].x=projectiles[id].x+msubx
		if collision(col5x5,projectiles[id].x,projectiles[id].y)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				projectiles[id].timer=0
			end
		else
			projectiles[id].ignore=0
		end
		-- Move Y
		projectiles[id].y=projectiles[id].y+msuby
		if collision(col5x5,projectiles[id].x,projectiles[id].y)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				projectiles[id].timer=0
			end
		else
			projectiles[id].ignore=0
		end	
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			-- Free projectile
			freeprojectile(id)
			break
		end
	end
	-- Timer -> Explode
	if projectiles[id].timer<=0 then
		-- Scroll to projectile
		scroll(projectiles[id].x,projectiles[id].y)
		-- Cause damage
		arealdamage(projectiles[id].x,projectiles[id].y,100,50)
		-- Destroy terrain
		terrainexplosion(projectiles[id].x,projectiles[id].y,15,1)
		-- Crater
		grey=math.random(0,40)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		else
			terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		end
		-- Fire
		createobject(o_fire,projectiles[id].x,projectiles[id].y)
		for a=45,360,45 do
			createobject(o_fire,projectiles[id].x+math.sin(math.rad(a))*40,projectiles[id].y-math.cos(math.rad(a))*40)
		end
		-- Free projectile
		freeprojectile(id)
	end
end