--------------------------------------------------------------------------------
-- Weapon Experimental Weapon + Projectile Ray
-- Script by Arne, November 2011
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.experimewep={}
cc.experimewep.ray={}

-- Load & Prepare Ressources
cc.experimewep.gfx_wpn=loadgfx("weapons/experimewep.bmp")			-- Weapon Image
setmidhandle(cc.experimewep.gfx_wpn)
cc.experimewep.gfx_pro=loadgfx("weapons/lasershot.png")				-- Projectile Image
setmidhandle(cc.experimewep.gfx_pro)
cc.experimewep.sfx_attack=loadsfx("LAZER.wav")						-- Attack Sound
cc.experimewep.sfx_water=loadsfx("hitwater3.wav")					-- Hit Water sound

--------------------------------------------------------------------------------
-- Weapon: Experimental Weapon
--------------------------------------------------------------------------------

cc.experimewep.id=addweapon("cc.experimewep","Experimental Weapon",cc.experimewep.gfx_wpn,0,2)	-- Add Weapon (0 uses, first in round 2)
cc.experimewep.ammo=1													-- 1 Shot

function cc.experimewep.draw()										-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	drawinhand(cc.experimewep.gfx_wpn,8,0)
	hudinfo("Attention: Hitting [Space] with this weapon might kill your own player!")
	-- HUD Crosshair
	if cc.experimewep.ammo-weapon_shots>0 then
		hudcrosshair(7,3)
	end
end

function cc.experimewep.attack(attack)										-- Attack
	if (weapon_shots<=0) then
		if (attack==1) then
			-- No more weapon switching!
			useweapon(0)
			weapon_shots=weapon_shots+1
			randomseed(getframe()*1415)
			if (random(1,100)<=65) then
		-- Reset Timer
		weapon_timer=15
		-- Attack
		playsound(cc.experimewep.sfx_attack)
		weapon_shots=weapon_shots+1
		id=createprojectile(cc.experimewep.ray.id)
		projectiles[id]={}
		-- Ignore collision with current player at beginning
		projectiles[id].ignore=playercurrent()
		-- Set initial position of projectile
		projectiles[id].x=getplayerx(0)+(7*getplayerdirection(0))-math.sin(math.rad(getplayerrotation(0)))*5.0
		projectiles[id].y=getplayery(0)+3+math.cos(math.rad(getplayerrotation(0)))*5.0
		-- Set speed of projectile
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*6.0
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*6.0
		-- Timer
		projectiles[id].timer=0
		-- Initial movement
		projectiles[id].x=projectiles[id].x-projectiles[id].sx*1.5
		projectiles[id].y=projectiles[id].y-projectiles[id].sy*1.5
		for i=1,3,1 do
			if cc.experimewep.ray.move(id)==1 then
				break
			end
		end
		-- Effects
		recoil(3)
		particle(p_muzzle,getplayerx(0)+(getplayerdirection(0)*7)+math.sin(math.rad(getplayerrotation(0)))*12,getplayery(0)+3-math.cos(math.rad(getplayerrotation(0)))*12)
		particlecolor(0,255,255)
		particlefadealpha(0.01)
		particle(p_smoke,getplayerx(0)+(getplayerdirection(0)*7)+math.sin(math.rad(getplayerrotation(0)))*12,getplayery(0)+3-math.cos(math.rad(getplayerrotation(0)))*12)
		particlespeed(-0.2+math.random()*0.4+getwind()*10.0,-1.0+math.random()*0.6)
		particlefadealpha(0.005)
			-- End Turn
			endturn()			
			else
			-- Suicide
			playerdamage(0,100000)
			-- Cause damage
			arealdamage(getplayerx(0),getplayery(0),120,90)
			-- Destroy terrain
			terrainexplosion(getplayerx(0),getplayery(0),50,1)
			-- Crater
			grey=math.random(0,40)
			if math.random(0,1)==1 then
				terrainalphaimage(gfx_crater150,getplayerx(0),getplayery(0),math.random(6,9)*0.1,grey,grey,grey)
			else
				terrainalphaimage(gfx_crater175,getplayerx(0),getplayery(0),math.random(6,9)*0.1,grey,grey,grey)
			end
			-- End Turn
			endturn()
			end
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: Ray
--------------------------------------------------------------------------------

cc.experimewep.ray.id=addprojectile("cc.experimewep.ray")			-- Add Projectile

function cc.experimewep.ray.draw(id)								-- Draw
	-- Setup draw mode
	setblend(blend_light)
	setalpha(1)
	setcolor(0,255,255)
	setscale(2.5,2.0)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.experimewep.gfx_pro,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.experimewep.ray.update(id)							-- Update
	-- Move
	cc.experimewep.ray.move(id)
end

function cc.experimewep.ray.move(id)
	-- Particle Tail
	particle(p_lightpuff,projectiles[id].x,projectiles[id].y)
	particlespeed(math.random(-5,5)*0.1,math.random(-5,5)*0.1)
	particlefadealpha(0.05)
	particlesize(math.random(20,40)*0.1,math.random(20,40)*0.1)
	particlecolor(0,255,255)
	-- Timer (free after 10 secs)
	projectiles[id].timer=projectiles[id].timer+1
	if projectiles[id].timer>500 then
		-- Free projectile
		freeprojectile(id)
		return 1
	end
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby		
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*3,projectiles[id].y-math.cos(math.rad(rot))*3)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				-- Cause damage
				arealdamage(projectiles[id].x,projectiles[id].y,65,150)
				-- Destroy terrain
				terrainexplosion(projectiles[id].x,projectiles[id].y,65,150)
				-- Crater
				grey=math.random(0,40)
				if math.random(0,1)==1 then
					terrainalphaimage(gfx_crater150,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
				else
					terrainalphaimage(gfx_crater175,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
				end
				-- Free projectile
				freeprojectile(id)
				return 1
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			playsound(cc.experimewep.sfx_water)
			particle(p_smoke,projectiles[id].x,projectiles[id].y)
			-- Free projectile
			freeprojectile(id)
			return 1
		end
	end
	-- Scroll to projectile
	scroll(projectiles[id].x,projectiles[id].y)
end