--------------------------------------------------------------------------------
-- Weapon Ice Launcher + Projectile Ice Grenade
-- Script by Arne, April 2011
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.icel={}
cc.icel.icegrenade={}

-- Load & Prepare Ressources
cc.icel.gfx_wpn=loadgfx("weapons/icebattery.bmp")				-- Weapon Image
setmidhandle(cc.icel.gfx_wpn)
cc.icel.gfx_pro=loadgfx("weapons/icegrenade.bmp")				-- Projectile Image
setmidhandle(cc.icel.gfx_pro)
cc.icel.gfx_ice=loadgfx("weapons/ice.bmp")						-- Impact Ice
cc.icel.sfx_attack=loadsfx("rocketrelease.wav")					-- Attack Sound
cc.icel.sfx_freeze=loadsfx("freeze.wav")						-- Freeze Sound

--------------------------------------------------------------------------------
-- Weapon: Missile Battery
--------------------------------------------------------------------------------

cc.icel.id=addweapon("cc.icel","Ice Launcher",cc.icel.gfx_wpn,0,3)	-- Add Weapon (0 uses, first in round 3)
cc.icel.ammo=3													-- 9 Missiles

function cc.icel.draw()											-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	drawinhand(cc.icel.gfx_wpn,6,0)
	-- HUD ammobar
	if cc.icel.ammo-weapon_shots>0 then
		hudammobar(cc.icel.ammo-weapon_shots,cc.icel.ammo)
	end
	-- HUD Crosshair
	if cc.icel.ammo-weapon_shots>0 then
		hudcrosshair(7,3)
	end
end

function cc.icel.attack(attack)									-- Attack
	-- Decrement timer
	if weapon_timer>0 then
		weapon_timer=weapon_timer-1
	end
	if (weapon_shots<cc.icel.ammo) and (attack==1) and (weapon_timer<=0) then
		-- No more weapon switching!
		useweapon(0)
		playsound(cc.icel.sfx_attack)
		weapon_shots=weapon_shots+1
		weapon_timer=15
		id=createprojectile(cc.icel.icegrenade.id)
		projectiles[id]={}
		-- Ignore collision with current player at beginning
		projectiles[id].ignore=playercurrent()
		-- Set initial position of projectile
		projectiles[id].x=getplayerx(0)+(6*getplayerdirection(0))+math.sin(math.rad(getplayerrotation(0)))*10.0
		projectiles[id].y=getplayery(0)+3-math.cos(math.rad(getplayerrotation(0)))*10.0
		-- Initial movement
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*20
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*20
		projectiles[id].x=projectiles[id].x-projectiles[id].sx
		projectiles[id].y=projectiles[id].y-projectiles[id].sy
		cc.icel.icegrenade.move(id,0)
		-- Set speed of projectile
		projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*10.0
		projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*10.0
		-- Effects
		recoil(5)
		-- End Turn
		if weapon_shots>=cc.icel.ammo then
			endturn()
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: ice grenade
--------------------------------------------------------------------------------

cc.icel.icegrenade.id=addprojectile("cc.icel.icegrenade")		-- Add Projectile

function cc.icel.icegrenade.draw(id)								-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.icel.gfx_pro,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.icel.icegrenade.update(id)							-- Update
	-- Move
	cc.icel.icegrenade.move(id,1)
end

function cc.icel.icegrenade.move(id,fx)
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Particle Tail
	if (fx==1) then
		particle(p_smoke,projectiles[id].x-math.sin(math.rad(rot))*7,projectiles[id].y+math.cos(math.rad(rot))*7)
		particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
		particlefadealpha(0.01)
		particlecolor(245,255,255)
		particle(p_lightpuff,projectiles[id].x-math.sin(math.rad(rot))*6,projectiles[id].y+math.cos(math.rad(rot))*6)
		particlefadealpha(0.04)
		particlecolor(245,255,255)
	end
	-- Wind + Gravity influence on speed
	projectiles[id].sx=projectiles[id].sx+getwind()*0.5
	projectiles[id].sy=projectiles[id].sy+getgravity()*1.5
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby
		-- Water
		if (projectiles[id].y)>getwatery()-45 then
		playsound(cc.icel.sfx_freeze)
		-- Crater
		blue=math.random(200,255)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		else
			terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		end
		-- Ice
		terrainimage(cc.icel.gfx_ice,projectiles[id].x,projectiles[id].y)
		-- Freeze Players
		players=playertable()
		for i=1,#players,1 do
			if getplayerhealth(players[i])>0 then
				if math.sqrt((getplayerx(players[i])-projectiles[id].x)^2+(getplayery(players[i])-projectiles[id].y)^2)<=45 then
					playerstate(players[i],state_frozen,1)
				end
			end
		end
		-- Particles
		particle(p_muzzle,projectiles[id].x,projectiles[id].y)
		particlecolor(255,255,255)
		for angle=0,350,10 do
			particle(p_smoke,projectiles[id].x,projectiles[id].y)
			particlespeed(math.sin(math.rad(angle))*2,-math.cos(math.rad(angle))*2)
			particlecolor(255,255,255)
		end
		-- Free Fire
		fire=objecttable(o_fire)
		for f=1,#fire do
			if math.sqrt((projectiles[id].x-getobjectx(fire[f]))^2+(projectiles[id].y-getobjecty(fire[f]))^2)<=75 then
				removeobject(fire[f])
			end
		end
		-- Free projectile
		freeprojectile(id)
	end
	-- Scroll to projectile
	scroll(projectiles[id].x,projectiles[id].y)
end
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*3,projectiles[id].y-math.cos(math.rad(rot))*3)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
		playsound(cc.icel.sfx_freeze)
		-- Crater
		blue=math.random(200,255)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		else
			terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,blue,blue,255)
		end
		-- Ice
		terrainimage(cc.icel.gfx_ice,projectiles[id].x,projectiles[id].y)
		-- Freeze Players
		players=playertable()
		for i=1,#players,1 do
			if getplayerhealth(players[i])>0 then
				if math.sqrt((getplayerx(players[i])-projectiles[id].x)^2+(getplayery(players[i])-projectiles[id].y)^2)<=45 then
					playerstate(players[i],state_frozen,1)
				end
			end
		end
		-- Particles
		particle(p_muzzle,projectiles[id].x,projectiles[id].y)
		particlecolor(255,255,255)
		for angle=0,350,10 do
			particle(p_smoke,projectiles[id].x,projectiles[id].y)
			particlespeed(math.sin(math.rad(angle))*2,-math.cos(math.rad(angle))*2)
			particlecolor(255,255,255)
		end
		-- Free projectile
		freeprojectile(id)
	end
	-- Scroll to projectile
	scroll(projectiles[id].x,projectiles[id].y)
	end
end