--------------------------------------------------------------------------------
-- Weapon Zombie Launcher + Projectile Zombie
-- Script by Arne, April 2011
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.zlauncher={}
cc.zlauncher.rocket={}

-- Load & Prepare Ressources
cc.zlauncher.gfx_wpn=loadgfx("weapons/zlauncher.bmp")					-- Weapon Image
setmidhandle(cc.zlauncher.gfx_wpn)
cc.zlauncher.gfx_pro=loadgfx("weapons/zombie.bmp")					-- Projectile Image
setmidhandle(cc.zlauncher.gfx_pro)
cc.zlauncher.sfx_attack=loadsfx("zo_attack.wav")					-- Attack Sound
cc.zlauncher.sfx_splat=loadsfx("splatter0.wav")

--------------------------------------------------------------------------------
-- Weapon: Zombie Launcher
--------------------------------------------------------------------------------

cc.zlauncher.id=addweapon("cc.zlauncher","Zombie Launcher",cc.zlauncher.gfx_pro)	-- Add Weapon

function cc.zlauncher.draw()											-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	drawinhand(cc.zlauncher.gfx_wpn,6,0)
	-- HUD chargebar
	if weapon_charge>0 and weapon_shots==0 then
		hudchargebar(weapon_charge,100)
	end
	-- HUD Crosshair
	if weapon_shots==0 then
		hudcrosshair(6,3)
	end
end

function cc.zlauncher.attack(attack)									-- Attack
	if (weapon_shots<=0) then
		-- Charge
		if (attack==1) then
			weapon_charge=weapon_charge+1							-- Increase charge
		end
		-- Fire a projectile (on release/full charge)
		if (attack==0 and weapon_charge>0) or (weapon_charge>=100) then
			-- No more weapon switching!
			useweapon(0)
			playsound(cc.zlauncher.sfx_attack)
			weapon_shots=weapon_shots+1
			id=createprojectile(cc.zlauncher.rocket.id)
			projectiles[id]={}
			-- Ignore collision with current player at beginning
			projectiles[id].ignore=playercurrent()
			-- Set initial position of projectile
			projectiles[id].x=getplayerx(0)+(6*getplayerdirection(0))+math.sin(math.rad(getplayerrotation(0)))*10.0
			projectiles[id].y=getplayery(0)+3-math.cos(math.rad(getplayerrotation(0)))*10.0
			-- Initial movement
			projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*20
			projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*20
			projectiles[id].x=projectiles[id].x-projectiles[id].sx
			projectiles[id].y=projectiles[id].y-projectiles[id].sy
			cc.zlauncher.rocket.move(id,0)
			-- Set speed of projectile
			projectiles[id].sx=math.sin(math.rad(getplayerrotation(0)))*(weapon_charge/100.0)*8.0
			projectiles[id].sy=-math.cos(math.rad(getplayerrotation(0)))*(weapon_charge/100.0)*8.0
			-- Effects
			recoil(2)
			-- End Turn
			endturn()
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: "Rocket" xD
--------------------------------------------------------------------------------

cc.zlauncher.rocket.id=addprojectile("cc.zlauncher.rocket")		-- Add Projectile

function cc.zlauncher.rocket.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(cc.zlauncher.gfx_pro,projectiles[id].x,projectiles[id].y)
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function cc.zlauncher.rocket.update(id)						-- Update
	-- Move
	cc.zlauncher.rocket.move(id,1)
end

function cc.zlauncher.rocket.move(id,fx)
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Particle Tail
	if (fx==1) then
		particle(p_smoke,projectiles[id].x-math.sin(math.rad(rot))*7,projectiles[id].y+math.cos(math.rad(rot))*7)
		particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
		particlefadealpha(0.01)
		particlecolor(0,128,0)
		particle(p_lightpuff,projectiles[id].x-math.sin(math.rad(rot))*6,projectiles[id].y+math.cos(math.rad(rot))*6)
		particlefadealpha(0.04)
		particlecolor(0,128,0)
	end
	-- Gravity influence on speed
	projectiles[id].sy=projectiles[id].sy+getgravity()
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*3,projectiles[id].y-math.cos(math.rad(rot))*3)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				-- Cause damage
				arealdamage(projectiles[id].x,projectiles[id].y,50,80)
				-- Destroy terrain
				terrainexplosion(projectiles[id].x,projectiles[id].y,8,1)
				-- Crater
				if math.random(0,1)==1 then
					terrainalphaimage(gfx_crater50,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,40,128,20)
				else
					terrainalphaimage(gfx_crater75,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,40,128,20)
				end
			playsound(cc.zlauncher.sfx_splat)
			particle(p_smoke,projectiles[id].x,projectiles[id].y)
			particlealpha(0.5)
			particlecolor(0,128,0)
			particlesize(30,30)
			particlefadealpha(0.005)
			for angle=0,340,20 do
				particle(p_smoke,projectiles[id].x,projectiles[id].y)
				particlespeed(math.sin(math.rad(angle))*0.5,-math.cos(math.rad(angle))*0.5)
				particlealpha(1.0)
				particlecolor(0,128,0)
				particlesize(20,20)
				particlefadealpha(0.009)
			  end
					-- Poison Players
					players=playertable()
					for i=1,#players,1 do
					if getplayerhealth(players[i])>0 then
					if math.sqrt((getplayerx(players[i])-projectiles[id].x)^2+(getplayery(players[i])-projectiles[id].y)^2)<=70 then
					playerstate(players[i],state_poisoned,1)
					end
				end
			end
			  -- Free projectile
			  freeprojectile(id)
			  return 1
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			-- Free projectile
			freeprojectile(id)
			return 1
		end
	end
	-- Scroll to projectile
	scroll(projectiles[id].x,projectiles[id].y)
end